@@ -10,6 +10,7 @@ from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.support.ui import Select
 from selenium.common.exceptions import NoSuchElementException        
 from selenium.common.exceptions import StaleElementReferenceException
+from selenium.webdriver.common.action_chains import ActionChains
 
 from selenium.webdriver.remote.remote_connection import LOGGER
 
@@ -101,9 +102,13 @@ class Selenium(Scraper):
                 element = element[0]
 
             try:
-                self.driver.execute_script("arguments[0].click();", element)
-            except Exception as e:
-                element.click()                
+                actions = ActionChains(self.driver)
+                actions.click(element).perform()
+            except:
+                try:
+                    self.driver.execute_script("arguments[0].click();", element)
+                except Exception as e:
+                    element.click()
 
             return element
         else:
